Type Definition melstructs::ConsensusProof
source · pub type ConsensusProof = BTreeMap<Ed25519PK, Bytes>;Expand description
A consensus proof is a mapping from signing key to signature.
pub type ConsensusProof = BTreeMap<Ed25519PK, Bytes>;A consensus proof is a mapping from signing key to signature.